Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java')
-rw-r--r--plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java22
1 files changed, 11 insertions, 11 deletions
diff --git a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java
index 3dc76a228..e6b28433f 100644
--- a/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java
+++ b/plugins/org.eclipse.etrice.core.room/src-gen/org/eclipse/etrice/core/room/Annotation.java
@@ -20,7 +20,7 @@ import org.eclipse.emf.ecore.EObject;
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.etrice.core.room.Annotation#getName <em>Name</em>}</li>
+ * <li>{@link org.eclipse.etrice.core.room.Annotation#getType <em>Type</em>}</li>
* <li>{@link org.eclipse.etrice.core.room.Annotation#getAttributes <em>Attributes</em>}</li>
* </ul>
* </p>
@@ -32,30 +32,30 @@ import org.eclipse.emf.ecore.EObject;
public interface Annotation extends EObject
{
/**
- * Returns the value of the '<em><b>Name</b></em>' attribute.
+ * Returns the value of the '<em><b>Type</b></em>' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* <!-- begin-model-doc -->
* <br>This is the name of the annotation.
*
* <!-- end-model-doc -->
* @return the value of the '<em>Name</em>' attribute.
* @see #setName(String)
* @see org.eclipse.etrice.core.room.RoomPackage#getAnnotation_Name()
* @model
* @generated
*/
- String getName();
+ AnnotationType getType();
/**
* Sets the value of the '{@link org.eclipse.etrice.core.room.Annotation#getName <em>Name</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Name</em>' attribute.
* @see #getName()
* @generated
*/
- void setName(String value);
+ void setType(AnnotationType value);
/**
* Returns the value of the '<em><b>Attributes</b></em>' containment reference list.
@@ -32,30 +32,30 @@ import org.eclipse.emf.ecore.EObject;
* <!-- end-user-doc -->
* <!-- begin-model-doc -->
- * <br>This is the name of the annotation.
+ * <br>This is the type of the annotation.
*
* <!-- end-model-doc -->
@@ -32,30 +32,30 @@ import org.eclipse.emf.ecore.EObject;
*
* <!-- end-model-doc -->
- * @return the value of the '<em>Name</em>' attribute.
- * @see #setName(String)
- * @see org.eclipse.etrice.core.room.RoomPackage#getAnnotation_Name()
+ * @return the value of the '<em>Type</em>' reference.
+ * @see #setType(AnnotationType)
+ * @see org.eclipse.etrice.core.room.RoomPackage#getAnnotation_Type()
* @model
* @generated
@@ -32,30 +32,30 @@ import org.eclipse.emf.ecore.EObject;
/**
- * Sets the value of the '{@link org.eclipse.etrice.core.room.Annotation#getName <em>Name</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.etrice.core.room.Annotation#getType <em>Type</em>}' reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -32,30 +32,30 @@ import org.eclipse.emf.ecore.EObject;
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Name</em>' attribute.
- * @see #getName()
+ * @param value the new value of the '<em>Type</em>' reference.
+ * @see #getType()
* @generated
*/

Back to the top